@@ -277,12 +277,13 @@ class GDriveSync():
         ################################################################################
         # Find changes between remote and local
         for item, pth in self.walk_syncable(drive_dir):
-            if self._should_exclude(pth, exclude):
+            pth_loc = os.path.join(local_dir, *pth)
+            
+            if self._should_exclude(pth_loc, exclude):
                 # This matched an exclude pattern
                 continue
             
             # Check if the local item is present
-            pth_loc = os.path.join(local_dir, *pth)
             if pth_loc in local_data:
                 local = local_data[pth_loc]
             elif os.path.exists(pth_loc):
@@ -322,7 +323,7 @@ class GDriveSync():
             for item in files + dirs:
                 pth_loc = os.path.join(root, item)
                 
-                if self._should_exclude(pth, exclude):
+                if self._should_exclude(pth_loc, exclude):
                     # This matched an exclude pattern
                     continue
                 
